@@ -4,6 +4,7 @@ coax.serial_interface
 """
 
 import struct
+from copy import copy
 from sliplib import SlipWrapper, ProtocolError
 
 from .interface import Interface
@@ -18,6 +19,9 @@ class SerialInterface(Interface):
 
         self.slip_serial = SlipSerial(self.serial)
 
+        self.legacy_firmware_detected = None
+        self.legacy_firmware_version = None
+
     def reset(self):
         original_serial_timeout = self.serial.timeout
 
@@ -37,42 +41,17 @@ class SerialInterface(Interface):
         if message[0] != 0x01:
             raise _convert_error(message)
 
-        if len(message) != 4:
+        if message[1:] == b'\x32\x70':
+            self.legacy_firmware_detected = False
+            self.legacy_firmware_version = None
+        elif len(message) == 4:
+            (major, minor, patch) = struct.unpack('BBB', message[1:])
+
+            self.legacy_firmware_detected = True
+            self.legacy_firmware_version = '{}.{}.{}'.format(major, minor, patch)
+        else:
             raise InterfaceError(f'Invalid reset response: {message}')
 
-        (major, minor, patch) = struct.unpack('BBB', message[1:])
-
-        return '{}.{}.{}'.format(major, minor, patch)
-
-    def transmit(self, words, repeat_count=None, repeat_offset=1):
-        message = bytes([0x02])
-
-        message += _pack_transmit_header(repeat_count, repeat_offset)
-        message += _pack_transmit_data(words)
-
-        self._write_message(message)
-
-        message = self._read_message()
-
-        if message[0] != 0x01:
-            raise _convert_error(message)
-
-    def receive(self, length=None, timeout=None):
-        timeout_milliseconds = self._calculate_timeout_milliseconds(timeout)
-
-        message = bytes([0x04])
-
-        message += _pack_receive_header(length, timeout_milliseconds)
-
-        self._write_message(message)
-
-        message = self._read_message()
-
-        if message[0] != 0x01:
-            raise _convert_error(message)
-
-        return _unpack_receive_data(message[1:])
-
     def transmit_receive(self, transmit_words, transmit_repeat_count=None,
                          transmit_repeat_offset=1, receive_length=None,
                          receive_timeout=None):
@@ -164,7 +143,7 @@ def _convert_error(message):
         return InterfaceError(f'Invalid error response: {message}')
 
     if message[1] in ERROR_MAP:
-        error = ERROR_MAP[message[1]]
+        error = copy(ERROR_MAP[message[1]])
 
         # Append description if included.
         if len(message) > 2:
